# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api.proto',
  package='v1alpha1',
  syntax='proto3',
  serialized_options=b'Z\013go/v1alpha1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tapi.proto\x12\x08v1alpha1\"\x07\n\x05\x45mpty\"\x1f\n\x0eIndexedRequest\x12\r\n\x05index\x18\x01 \x01(\r\"W\n\x0eStatusResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x13\n\x0b\x63ompileTime\x18\x02 \x01(\t\x12\x1f\n\x06relays\x18\x03 \x03(\x0b\x32\x0f.v1alpha1.Relay\"%\n\x05Relay\x12\r\n\x05index\x18\x01 \x01(\r\x12\r\n\x05state\x18\x02 \x01(\x08\x32\xa9\x02\n\x0cStripService\x12\x35\n\x06Status\x12\x0f.v1alpha1.Empty\x1a\x18.v1alpha1.StatusResponse\"\x00\x12<\n\x0bWatchStatus\x12\x0f.v1alpha1.Empty\x1a\x18.v1alpha1.StatusResponse\"\x00\x30\x01\x12\x35\n\x06Toggle\x12\x18.v1alpha1.IndexedRequest\x1a\x0f.v1alpha1.Empty\"\x00\x12\x35\n\x06TurnOn\x12\x18.v1alpha1.IndexedRequest\x1a\x0f.v1alpha1.Empty\"\x00\x12\x36\n\x07TurnOff\x12\x18.v1alpha1.IndexedRequest\x1a\x0f.v1alpha1.Empty\"\x00\x42\rZ\x0bgo/v1alpha1b\x06proto3'
)




_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='v1alpha1.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23,
  serialized_end=30,
)


_INDEXEDREQUEST = _descriptor.Descriptor(
  name='IndexedRequest',
  full_name='v1alpha1.IndexedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='v1alpha1.IndexedRequest.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32,
  serialized_end=63,
)


_STATUSRESPONSE = _descriptor.Descriptor(
  name='StatusResponse',
  full_name='v1alpha1.StatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='v1alpha1.StatusResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compileTime', full_name='v1alpha1.StatusResponse.compileTime', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relays', full_name='v1alpha1.StatusResponse.relays', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=152,
)


_RELAY = _descriptor.Descriptor(
  name='Relay',
  full_name='v1alpha1.Relay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='v1alpha1.Relay.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='v1alpha1.Relay.state', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=191,
)

_STATUSRESPONSE.fields_by_name['relays'].message_type = _RELAY
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['IndexedRequest'] = _INDEXEDREQUEST
DESCRIPTOR.message_types_by_name['StatusResponse'] = _STATUSRESPONSE
DESCRIPTOR.message_types_by_name['Relay'] = _RELAY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:v1alpha1.Empty)
  })
_sym_db.RegisterMessage(Empty)

IndexedRequest = _reflection.GeneratedProtocolMessageType('IndexedRequest', (_message.Message,), {
  'DESCRIPTOR' : _INDEXEDREQUEST,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:v1alpha1.IndexedRequest)
  })
_sym_db.RegisterMessage(IndexedRequest)

StatusResponse = _reflection.GeneratedProtocolMessageType('StatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATUSRESPONSE,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:v1alpha1.StatusResponse)
  })
_sym_db.RegisterMessage(StatusResponse)

Relay = _reflection.GeneratedProtocolMessageType('Relay', (_message.Message,), {
  'DESCRIPTOR' : _RELAY,
  '__module__' : 'api_pb2'
  # @@protoc_insertion_point(class_scope:v1alpha1.Relay)
  })
_sym_db.RegisterMessage(Relay)


DESCRIPTOR._options = None

_STRIPSERVICE = _descriptor.ServiceDescriptor(
  name='StripService',
  full_name='v1alpha1.StripService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=194,
  serialized_end=491,
  methods=[
  _descriptor.MethodDescriptor(
    name='Status',
    full_name='v1alpha1.StripService.Status',
    index=0,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_STATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchStatus',
    full_name='v1alpha1.StripService.WatchStatus',
    index=1,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_STATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Toggle',
    full_name='v1alpha1.StripService.Toggle',
    index=2,
    containing_service=None,
    input_type=_INDEXEDREQUEST,
    output_type=_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TurnOn',
    full_name='v1alpha1.StripService.TurnOn',
    index=3,
    containing_service=None,
    input_type=_INDEXEDREQUEST,
    output_type=_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TurnOff',
    full_name='v1alpha1.StripService.TurnOff',
    index=4,
    containing_service=None,
    input_type=_INDEXEDREQUEST,
    output_type=_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STRIPSERVICE)

DESCRIPTOR.services_by_name['StripService'] = _STRIPSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import power_strip.v1alpha1.api_pb2 as api__pb2


class StripServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Status = channel.unary_unary(
                '/v1alpha1.StripService/Status',
                request_serializer=api__pb2.Empty.SerializeToString,
                response_deserializer=api__pb2.StatusResponse.FromString,
                )
        self.WatchStatus = channel.unary_stream(
                '/v1alpha1.StripService/WatchStatus',
                request_serializer=api__pb2.Empty.SerializeToString,
                response_deserializer=api__pb2.StatusResponse.FromString,
                )
        self.Toggle = channel.unary_unary(
                '/v1alpha1.StripService/Toggle',
                request_serializer=api__pb2.IndexedRequest.SerializeToString,
                response_deserializer=api__pb2.Empty.FromString,
                )
        self.TurnOn = channel.unary_unary(
                '/v1alpha1.StripService/TurnOn',
                request_serializer=api__pb2.IndexedRequest.SerializeToString,
                response_deserializer=api__pb2.Empty.FromString,
                )
        self.TurnOff = channel.unary_unary(
                '/v1alpha1.StripService/TurnOff',
                request_serializer=api__pb2.IndexedRequest.SerializeToString,
                response_deserializer=api__pb2.Empty.FromString,
                )


class StripServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Status(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Toggle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TurnOn(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TurnOff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StripServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Status': grpc.unary_unary_rpc_method_handler(
                    servicer.Status,
                    request_deserializer=api__pb2.Empty.FromString,
                    response_serializer=api__pb2.StatusResponse.SerializeToString,
            ),
            'WatchStatus': grpc.unary_stream_rpc_method_handler(
                    servicer.WatchStatus,
                    request_deserializer=api__pb2.Empty.FromString,
                    response_serializer=api__pb2.StatusResponse.SerializeToString,
            ),
            'Toggle': grpc.unary_unary_rpc_method_handler(
                    servicer.Toggle,
                    request_deserializer=api__pb2.IndexedRequest.FromString,
                    response_serializer=api__pb2.Empty.SerializeToString,
            ),
            'TurnOn': grpc.unary_unary_rpc_method_handler(
                    servicer.TurnOn,
                    request_deserializer=api__pb2.IndexedRequest.FromString,
                    response_serializer=api__pb2.Empty.SerializeToString,
            ),
            'TurnOff': grpc.unary_unary_rpc_method_handler(
                    servicer.TurnOff,
                    request_deserializer=api__pb2.IndexedRequest.FromString,
                    response_serializer=api__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1alpha1.StripService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StripService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Status(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1alpha1.StripService/Status',
            api__pb2.Empty.SerializeToString,
            api__pb2.StatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/v1alpha1.StripService/WatchStatus',
            api__pb2.Empty.SerializeToString,
            api__pb2.StatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Toggle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1alpha1.StripService/Toggle',
            api__pb2.IndexedRequest.SerializeToString,
            api__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TurnOn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1alpha1.StripService/TurnOn',
            api__pb2.IndexedRequest.SerializeToString,
            api__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TurnOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1alpha1.StripService/TurnOff',
            api__pb2.IndexedRequest.SerializeToString,
            api__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
